

<h1 align="center">Gordo</h1>
<div align="center">
 <!-- Uncomment line below once we decided on 'logo.png' -->
 <!--<img align="center" src="logo.png" width="250" height="250">-->
 <br />
 <strong>
   Building thousands of models with timeseries data to monitor systems.
 </strong>
</div>

<br />

<div align="center">
  <a href="https://github.com/equinor/gordo/actions?query=branch=master">
    <img src="https://github.com/equinor/gordo/workflows/CI/badge.svg?branch=master" alt="Build Status"/>
  </a>
  <a href="https://codecov.io/gh/equinor/gordo">
    <img src="https://codecov.io/gh/equinor/gordo/branch/master/graph/badge.svg" alt="Codecov"/>
  </a>
  <a href="https://gordo.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/gordo/badge/?version=latest" alt="Documentation"/>
  </a> 
</div>

---

## About:

Gordo fulfills the role of inhaling config files and supplying components to the pipeline of:

1. Fetching data
2. Training model
3. Serving model

---

## Examples

See our [example](./examples) notebooks for how to develop with `gordo` locally.

---

## Install: 
`pip install --upgrade gordo`  

Bleeding edge:  
`pip install git+https://github.com/equinor/gordo.git`

## Uninstall:
`pip uninstall gordo`
